from .. import *
from .base import *

class Splitter(QtBaseWidget):
    pui_terminal = False
    def __init__(self, vertical=False):
        super().__init__()
        self.vertical = vertical

    def update(self, prev):
        if prev and prev.ui:
            self.ui = prev.ui
        else:
            self.ui = QtWidgets.QSplitter()
        self.ui.setOrientation(QtCore.Qt.Orientation.Vertical if self.vertical else QtCore.Qt.Orientation.Horizontal)
        super().update(prev)

    def addChild(self, idx, child):
        if isinstance(child, QtBaseWidget) or isinstance(child, QtBaseLayout):
            self.ui.insertWidget(idx, child.outer)
        else:
            self.addChild(idx, child.children[0])
    
    def removeChild(self, idx, child):
        child.outer.setParent(None)



__version__ = "0.22"

from .node import *
from .view import *
from .state import *
from .timeline import *
from .decorator import *
from .common import *
from .interfaces import *

try:
    import jurigged
    w = jurigged.watch("/")
    def postrun(path, cf):
        PUIView.reload()
    w.postrun.register(postrun)
except ImportError:
    pass

class Prop():
    def __init__(self, value=None):
        self.value = value

    def set(self, value):
        changed = (self.value != value)
        self.value = value
        return changed

class NotImplementedNode():
    def __init__(self, *args, **kwargs):
        print("Not Implemented")
        import traceback
        import inspect
        traceback.print_stack(inspect.currentframe().f_back, 1)

    def __enter__(self):
        return self

    def __exit__(self, *args):
        pass

    def layout(self, *args, **kwargs):
        return self

    def style(self, *args, **kwargs):
        return self


from .. import *
from .base import *

class Text(TkBaseWidget):
    def __init__(self, text, selectable=False):
        super().__init__()
        self.text = text

    def update(self, prev):
        if prev and prev.ui:
            self.ui = prev.ui
            self.ui.config(text = self.text)
        else:
            self.ui = tk.Label(self.tkparent.inner, text=self.text, anchor="w", justify="left")

class Html(Text):
    pui_supported = False

class MarkDown(Text):
    pui_supported = False
